@@ -2,8 +2,8 @@ package Activiti::Rest::Response;
 use Activiti::Sane;
 use Activiti::Rest::Error;
 use Moo;
-use JSON qw(decode_json);
-use Encode qw(decode);
+use JSON qw();
+use Encode qw();
 
 has content => (
   is => 'ro',
@@ -30,44 +30,54 @@ sub from_http_response {
 
     my $code = $res->code;
 
+    my $args = {
+        status_code => $res->code,
+        message => $res->message,
+        content => $res->content,
+        content_type => $res->content_type,
+        error_message => JSON::decode_json($res->content)->{errorMessage}
+    };
+
+    #{ "errorMessage": "<errorMessage>", "statusCode": "statusCode" }
+
     #The operation failed. The operation requires an Authentication header to be set. If this was present in the request, the supplied credentials are not valid or the user is not authorized to perform this operation.
     if($code eq "401"){
-      Activiti::Rest::Error::UnAuthorized->throw($res->message);
+      Activiti::Rest::Error::UnAuthorized->throw($args);
     }
 
     #The operation is forbidden and should not be re-attempted. This does not imply an issue with authentication not authorization, it's an operation that is not allowed. Example: deleting a task that is part of a running process is not allowed and will never be allowed, regardless of the user or process/task state.
     elsif($code eq "403"){
-      Activiti::Rest::Error::Forbidden->throw($res->message);
+      Activiti::Rest::Error::Forbidden->throw($args);
     }
 
     #The operation failed.The requested resource was not found.
     elsif($code eq "404"){
-      Activiti::Rest::Error::NotFound->throw($res->message);
+      Activiti::Rest::Error::NotFound->throw($args);
     }
 
     #The operation failed. The used method is not allowed for this resource. Eg. trying to update (PUT) a deployment-resource will result in a 405 status.
     elsif($code eq "405"){
-      Activiti::Rest::Error::MethodNotAllowed->throw($res->message);
+      Activiti::Rest::Error::MethodNotAllowed->throw($args);
     }
 
     #The operation failed. The operation causes an update of a resource that has been updated by another operation, which makes the update no longer valid. Can also indicate a resource that is being created in a collection where a resource with that identifier already exists.
     elsif($code eq "409"){
-      Activiti::Rest::Error::Conflict->throw($res->message);
+      Activiti::Rest::Error::Conflict->throw($args);
     }
 
     #The operation failed. The request body contains an unsupported media type. Also occurs when the request-body JSON contains an unknown attribute or value that doesn't have the right format/type to be accepted.
     elsif($code eq "415"){
-      Activiti::Rest::Error::UnsupportedMediaType->throw($res->message);
+      Activiti::Rest::Error::UnsupportedMediaType->throw($args);
     }
 
     #The operation failed. An unexpected exception occurred while executing the operation. The response-body contains details about the error.
     elsif($code eq "500"){
-      Activiti::Rest::Error::InternalServerError->throw($res->content);
+      Activiti::Rest::Error::InternalServerError->throw($args);
     }
 
     #common error
     else{
-      Activiti::Rest::Error->throw($res->message);
+      Activiti::Rest::Error->throw($args);
     }
 
   }
@@ -85,9 +95,9 @@ sub from_http_response {
     $new_args{content} = $res->content;
 
     if($content_type =~ /json/o){
-      $new_args{parsed_content} = decode_json($res->content);
+      $new_args{parsed_content} = JSON::decode_json($res->content);
     }elsif($content_type =~ /xml/o){
-      $new_args{parsed_content} = decode('UTF-8',$res->content);
+      $new_args{parsed_content} = Encode::decode('UTF-8',$res->content);
     }
 
   }
